PROLOG = (
    "<?xml version='1.0' encoding='UTF-8' standalone='yes'?>"
    '<w:document xmlns:wpc="http://schemas.microsoft.com/office/word/2010/wordprocessingCanvas" xmlns:mo="http://schemas.microsoft.com/office/mac/office/2008/main" xmlns:mc="http://schemas.openxmlformats.org/markup-compatibility/2006" xmlns:mv="urn:schemas-microsoft-com:mac:vml" xmlns:o="urn:schemas-microsoft-com:office:office" xmlns:r="http://schemas.openxmlformats.org/officeDocument/2006/relationships" xmlns:m="http://schemas.openxmlformats.org/officeDocument/2006/math" xmlns:v="urn:schemas-microsoft-com:vml" xmlns:wp14="http://schemas.microsoft.com/office/word/2010/wordprocessingDrawing" xmlns:wp="http://schemas.openxmlformats.org/drawingml/2006/wordprocessingDrawing" xmlns:w10="urn:schemas-microsoft-com:office:word" xmlns:w="http://schemas.openxmlformats.org/wordprocessingml/2006/main" xmlns:w14="http://schemas.microsoft.com/office/word/2010/wordml" xmlns:wpg="http://schemas.microsoft.com/office/word/2010/wordprocessingGroup" xmlns:wpi="http://schemas.microsoft.com/office/word/2010/wordprocessingInk" xmlns:wne="http://schemas.microsoft.com/office/word/2006/wordml" xmlns:wps="http://schemas.microsoft.com/office/word/2010/wordprocessingShape" mc:Ignorable="w14 wp14">'
    "<w:body>"
)

EPILOG = (
    '<w:sectPr w:rsidR="00FC693F" w:rsidRPr="0006063C" w:rsidSect="00034616">'
    '<w:pgSz w:w="12240" w:h="15840"/>'
    '<w:pgMar w:top="1440" w:right="1800" w:bottom="1440" w:left="1800" w:header="720" w:footer="720" w:gutter="0"/>'
    '<w:cols w:space="720"/>'
    '<w:docGrid w:linePitch="360"/>'
    "</w:sectPr>"
    "</w:body>"
    "</w:document>"
)

PAGE = (
    "<w:p>"
    "<w:pPr>"
    '<w:pStyle w:val="PagePara"/>'
    "</w:pPr>"
    "<w:r>"
    "<w:t>{}</w:t>"
    "</w:r>"
    "</w:p>"
)

PANEL = (
    "<w:p>"
    "<w:pPr>"
    '<w:pStyle w:val="PanelPara"/>'
    "</w:pPr>"
    "<w:r>"
    "<w:t>PANEL {}</w:t>"
    "</w:r>"
    "</w:p>"
)

QUOTE = '<w:p><w:pPr><w:pStyle w:val="QuotePara"/></w:pPr></w:p>'
